==> active-viz-0.1.2-20190329.105847-1.jar: public/cljs-out/test/active_viz/interpolation/monotone_cubic_interpolation.js <==
// Compiled by ClojureScript 1.10.339 {}
goog.provide('active_viz.interpolation.monotone_cubic_interpolation');
goog.require('cljs.core');
goog.require('active_viz.interpolation.util');
/**
 * Compute the normalized tangent vector from the slopes. Note that if x is
 *   not monotonic, it's possible that the slope will be infinite, so we protect
 *   against NaN by setting the coordinate to zero.
 */
active_viz.interpolation.monotone_cubic_interpolation.normalize_tagents = (function active_viz$interpolation$monotone_cubic_interpolation$normalize_tagents(points,m,smoothness){
var f = (function active_viz$interpolation$monotone_cubic_interpolation$normalize_tagents_$_f(p_1,p_PLUS_1,m__$1){
var vec__7937 = p_1;
var x1 = cljs.core.nth.call(null,vec__7937,(0),null);
var _ = cljs.core.nth.call(null,vec__7937,(1),null);
var vec__7940 = p_PLUS_1;
var x2 = cljs.core.nth.call(null,vec__7940,(0),null);
var ___$1 = cljs.core.nth.call(null,vec__7940,(1),null);
var q = (smoothness * (Math.pow(m__$1,(2)) + (1)));
var s = ((x2 - x1) / q);
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [active_viz.interpolation.util.number_or_zero.call(null,s),active_viz.interpolation.util.number_or_zero.call(null,(m__$1 * s))], null);
});
var c = cljs.core.count.call(null,m);
return cljs.core.map_indexed.call(null,((function (c){
return (function (idx,m_SINGLEQUOTE_){
if(cljs.core._EQ_.call(null,(0),idx)){
return f.call(null,cljs.core.first.call(null,points),cljs.core.get.call(null,points,(idx + (1))),m_SINGLEQUOTE_);
} else {
if(cljs.core._EQ_.call(null,(idx - (1)),c)){
return f.call(null,cljs.core.get.call(null,points,(idx - (1))),cljs.core.last.call(null,points),m_SINGLEQUOTE_);
} else {
return f.call(null,cljs.core.get.call(null,points,(idx - (1))),cljs.core.get.call(null,points,(idx + (1))),m_SINGLEQUOTE_);

}
}
});})(c))
,m);
});
/**
 * Interpolates the given points using Fritsch-Carlson Monotone cubic Hermite interpolation. 
 * 
 * 
 *   Expects at least 3 points sorted monotonically by the x coordinate. 
 * 
 * 
 *   An optional parameter "smoothness" can be specified to adjust smoothing. A value between 2 and 10 is
 *   recommended, where 2 is very smooth and 10 less smooth. 
 * 
 *   Note: A proper smoothing factor depends on the data-scale described by points. Defaults to 6. 
 * 
 * 
 *   Returns an array of tangent vectors (which is a vector of length 2). 
 * 
 * 
 *   For details, see http://en.wikipedia.org/wiki/Monotone_cubic_interpolation
 */
active_viz.interpolation.monotone_cubic_interpolation.interpolate = (function active_viz$interpolation$monotone_cubic_interpolation$interpolate(var_args){
var args__4534__auto__ = [];
var len__4531__auto___7960 = arguments.length;
var i__4532__auto___7961 = (0);
while(true){
if((i__4532__auto___7961 < len__4531__auto___7960)){
args__4534__auto__.push((arguments[i__4532__auto___7961]));

var G__7962 = (i__4532__auto___7961 + (1));
i__4532__auto___7961 = G__7962;
continue;
} else {
}
break;
}

var argseq__4535__auto__ = ((((1) < args__4534__auto__.length))?(new cljs.core.IndexedSeq(args__4534__auto__.slice((1)),(0),null)):null);
return active_viz.interpolation.monotone_cubic_interpolation.interpolate.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__4535__auto__);
});

active_viz.interpolation.monotone_cubic_interpolation.interpolate.cljs$core$IFn$_invoke$arity$variadic = (function (points,p__7945){
var vec__7946 = p__7945;
var smoothness = cljs.core.nth.call(null,vec__7946,(0),null);
var smoothness__$1 = (function (){var or__3949__auto__ = smoothness;
if(cljs.core.truth_(or__3949__auto__)){
return or__3949__auto__;
} else {
return (6);
}
})();
var points__$1 = ((cljs.core.vector_QMARK_.call(null,points))?points:cljs.core.vec.call(null,points));
var fds = active_viz.interpolation.util.finite_differences.call(null,points__$1);
var p_PLUS_fds = cljs.core.map.call(null,cljs.core.vector,points__$1,fds);
var vec__7949 = cljs.core.first.call(null,p_PLUS_fds);
var p0 = cljs.core.nth.call(null,vec__7949,(0),null);
var m0 = cljs.core.nth.call(null,vec__7949,(1),null);
var p_PLUS_fds_STAR_ = cljs.core.rest.call(null,p_PLUS_fds);
return ((function (smoothness__$1,points__$1,fds,p_PLUS_fds,vec__7949,p0,m0,p_PLUS_fds_STAR_,vec__7946,smoothness){
return (function (p){
return active_viz.interpolation.monotone_cubic_interpolation.normalize_tagents.call(null,cljs.core.vec.call(null,points__$1),p,smoothness__$1);
});})(smoothness__$1,points__$1,fds,p_PLUS_fds,vec__7949,p0,m0,p_PLUS_fds_STAR_,vec__7946,smoothness))
.call(null,cljs.core.reverse.call(null,cljs.core.first.call(null,cljs.core.reduce.call(null,((function (smoothness__$1,points__$1,fds,p_PLUS_fds,vec__7949,p0,m0,p_PLUS_fds_STAR_,vec__7946,smoothness){
return (function (p__7952,p__7953){
var vec__7954 = p__7952;
var acc = cljs.core.nth.call(null,vec__7954,(0),null);
var prev_point = cljs.core.nth.call(null,vec__7954,(1),null);
var vec__7957 = p__7953;
var point = cljs.core.nth.call(null,vec__7957,(0),null);
var m = cljs.core.nth.call(null,vec__7957,(1),null);
var prev_m = cljs.core.first.call(null,acc);
var acc_STAR_ = cljs.core.rest.call(null,acc);
var d = active_viz.interpolation.util.slope.call(null,prev_point,point);
if((active_viz.interpolation.util.eps > Math.abs(d))){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cons.call(null,(0),cljs.core.cons.call(null,(0),acc_STAR_)),point], null);
} else {
var a = (prev_m / d);
var b = (m / d);
var s = ((b * b) + (a * a));
if((s > (9))){
var s__$1 = ((d * (3)) / Math.sqrt(s));
var m_prev_STAR_ = (s__$1 * a);
var m_STAR_ = (s__$1 * b);
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cons.call(null,m_STAR_,cljs.core.cons.call(null,m_prev_STAR_,acc_STAR_)),point], null);
} else {
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cons.call(null,m,acc),point], null);
}
}
});})(smoothness__$1,points__$1,fds,p_PLUS_fds,vec__7949,p0,m0,p_PLUS_fds_STAR_,vec__7946,smoothness))
,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [m0], null),p0], null),p_PLUS_fds_STAR_))));
});

active_viz.interpolation.monotone_cubic_interpolation.interpolate.cljs$lang$maxFixedArity = (1);

/** @this {Function} */
active_viz.interpolation.monotone_cubic_interpolation.interpolate.cljs$lang$applyTo = (function (seq7943){
var G__7944 = cljs.core.first.call(null,seq7943);
var seq7943__$1 = cljs.core.next.call(null,seq7943);
var self__4518__auto__ = this;
return self__4518__auto__.cljs$core$IFn$_invoke$arity$variadic(G__7944,seq7943__$1);
});


//# sourceMappingURL=monotone_cubic_interpolation.js.map

==> active-viz-0.2.1.jar: public/cljs-out/test/active_viz/interpolation/monotone_cubic_interpolation.js <==
// Compiled by ClojureScript 1.10.339 {}
goog.provide('active_viz.interpolation.monotone_cubic_interpolation');
goog.require('cljs.core');
goog.require('active_viz.interpolation.util');
/**
 * Compute the normalized tangent vector from the slopes. Note that if x is
 *   not monotonic, it's possible that the slope will be infinite, so we protect
 *   against NaN by setting the coordinate to zero.
 */
active_viz.interpolation.monotone_cubic_interpolation.normalize_tagents = (function active_viz$interpolation$monotone_cubic_interpolation$normalize_tagents(points,m,smoothness){
var f = (function active_viz$interpolation$monotone_cubic_interpolation$normalize_tagents_$_f(p_1,p_PLUS_1,m__$1){
var vec__7583 = p_1;
var x1 = cljs.core.nth.call(null,vec__7583,(0),null);
var _ = cljs.core.nth.call(null,vec__7583,(1),null);
var vec__7586 = p_PLUS_1;
var x2 = cljs.core.nth.call(null,vec__7586,(0),null);
var ___$1 = cljs.core.nth.call(null,vec__7586,(1),null);
var q = (smoothness * (Math.pow(m__$1,(2)) + (1)));
var s = ((x2 - x1) / q);
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [active_viz.interpolation.util.number_or_zero.call(null,s),active_viz.interpolation.util.number_or_zero.call(null,(m__$1 * s))], null);
});
var c = cljs.core.count.call(null,m);
return cljs.core.map_indexed.call(null,((function (c){
return (function (idx,m_SINGLEQUOTE_){
if(cljs.core._EQ_.call(null,(0),idx)){
return f.call(null,cljs.core.first.call(null,points),cljs.core.get.call(null,points,(idx + (1))),m_SINGLEQUOTE_);
} else {
if(cljs.core._EQ_.call(null,(idx - (1)),c)){
return f.call(null,cljs.core.get.call(null,points,(idx - (1))),cljs.core.last.call(null,points),m_SINGLEQUOTE_);
} else {
return f.call(null,cljs.core.get.call(null,points,(idx - (1))),cljs.core.get.call(null,points,(idx + (1))),m_SINGLEQUOTE_);

}
}
});})(c))
,m);
});
/**
 * Interpolates the given points using Fritsch-Carlson Monotone cubic Hermite interpolation. 
 * 
 * 
 *   Expects at least 3 points sorted by the x coordinate. 
 * 
 * 
 *   An optional parameter "smoothness" can be specified to adjust smoothing. A value between 2 and 10 is
 *   recommended, where 2 is very smooth and 10 less smooth. 
 * 
 *   Note: A proper smoothing factor depends on the data-scale described by points. Defaults to 6. 
 * 
 * 
 *   Returns an array of tangent vectors (which is a vector of length 2). 
 * 
 * 
 *   For details, see http://en.wikipedia.org/wiki/Monotone_cubic_interpolation
 */
active_viz.interpolation.monotone_cubic_interpolation.interpolate = (function active_viz$interpolation$monotone_cubic_interpolation$interpolate(var_args){
var args__4534__auto__ = [];
var len__4531__auto___7606 = arguments.length;
var i__4532__auto___7607 = (0);
while(true){
if((i__4532__auto___7607 < len__4531__auto___7606)){
args__4534__auto__.push((arguments[i__4532__auto___7607]));

var G__7608 = (i__4532__auto___7607 + (1));
i__4532__auto___7607 = G__7608;
continue;
} else {
}
break;
}

var argseq__4535__auto__ = ((((1) < args__4534__auto__.length))?(new cljs.core.IndexedSeq(args__4534__auto__.slice((1)),(0),null)):null);
return active_viz.interpolation.monotone_cubic_interpolation.interpolate.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__4535__auto__);
});

active_viz.interpolation.monotone_cubic_interpolation.interpolate.cljs$core$IFn$_invoke$arity$variadic = (function (points,p__7591){
var vec__7592 = p__7591;
var smoothness = cljs.core.nth.call(null,vec__7592,(0),null);
var smoothness__$1 = (function (){var or__3949__auto__ = smoothness;
if(cljs.core.truth_(or__3949__auto__)){
return or__3949__auto__;
} else {
return (6);
}
})();
var points__$1 = ((cljs.core.vector_QMARK_.call(null,points))?points:cljs.core.vec.call(null,points));
var fds = active_viz.interpolation.util.finite_differences.call(null,points__$1);
var p_PLUS_fds = cljs.core.map.call(null,cljs.core.vector,points__$1,fds);
var vec__7595 = cljs.core.first.call(null,p_PLUS_fds);
var p0 = cljs.core.nth.call(null,vec__7595,(0),null);
var m0 = cljs.core.nth.call(null,vec__7595,(1),null);
var p_PLUS_fds_STAR_ = cljs.core.rest.call(null,p_PLUS_fds);
var $ = p_PLUS_fds_STAR_;
var $__$1 = cljs.core.reduce.call(null,((function ($,smoothness__$1,points__$1,fds,p_PLUS_fds,vec__7595,p0,m0,p_PLUS_fds_STAR_,vec__7592,smoothness){
return (function (p__7598,p__7599){
var vec__7600 = p__7598;
var acc = cljs.core.nth.call(null,vec__7600,(0),null);
var prev_point = cljs.core.nth.call(null,vec__7600,(1),null);
var vec__7603 = p__7599;
var point = cljs.core.nth.call(null,vec__7603,(0),null);
var m = cljs.core.nth.call(null,vec__7603,(1),null);
var prev_m = cljs.core.first.call(null,acc);
var acc_STAR_ = cljs.core.rest.call(null,acc);
var d = active_viz.interpolation.util.slope.call(null,prev_point,point);
if((active_viz.interpolation.util.eps > Math.abs(d))){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cons.call(null,(0),cljs.core.cons.call(null,(0),acc_STAR_)),point], null);
} else {
var a = (prev_m / d);
var b = (m / d);
var s = ((b * b) + (a * a));
if((s > (9))){
var s__$1 = ((d * (3)) / Math.sqrt(s));
var m_prev_STAR_ = (s__$1 * a);
var m_STAR_ = (s__$1 * b);
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cons.call(null,m_STAR_,cljs.core.cons.call(null,m_prev_STAR_,acc_STAR_)),point], null);
} else {
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.cons.call(null,m,acc),point], null);
}
}
});})($,smoothness__$1,points__$1,fds,p_PLUS_fds,vec__7595,p0,m0,p_PLUS_fds_STAR_,vec__7592,smoothness))
,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [m0], null),p0], null),$);
var $__$2 = cljs.core.first.call(null,$__$1);
var $__$3 = cljs.core.reverse.call(null,$__$2);
return active_viz.interpolation.monotone_cubic_interpolation.normalize_tagents.call(null,cljs.core.vec.call(null,points__$1),$__$3,smoothness__$1);
});

active_viz.interpolation.monotone_cubic_interpolation.interpolate.cljs$lang$maxFixedArity = (1);

/** @this {Function} */
active_viz.interpolation.monotone_cubic_interpolation.interpolate.cljs$lang$applyTo = (function (seq7589){
var G__7590 = cljs.core.first.call(null,seq7589);
var seq7589__$1 = cljs.core.next.call(null,seq7589);
var self__4518__auto__ = this;
return self__4518__auto__.cljs$core$IFn$_invoke$arity$variadic(G__7590,seq7589__$1);
});


//# sourceMappingURL=monotone_cubic_interpolation.js.map
